pub fn ws_message_rate_limiter(url: &str) -> LighterWsMessageRateLimiterExpand description
Returns the shared WS message limiter for url, creating it on first
access. Subsequent calls with the same url return the same Arc.
pub fn ws_message_rate_limiter(url: &str) -> LighterWsMessageRateLimiterReturns the shared WS message limiter for url, creating it on first
access. Subsequent calls with the same url return the same Arc.