ws_message_rate_limiter

Function ws_message_rate_limiter 

pub fn ws_message_rate_limiter(url: &str) -> LighterWsMessageRateLimiter
Returns the shared WS message limiter for url, creating it on first access. Subsequent calls with the same url return the same Arc.

Panics

Panics if the registry mutex is poisoned by a prior panic while holding the lock.